#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pantry
version:              0.8.3
visibility:           public
id:                   pantry-0.8.3-HeGJd6loLMhEqqlWfpBGUy
key:                  pantry-0.8.3-HeGJd6loLMhEqqlWfpBGUy
license:              BSD-3-Clause
copyright:            2018-2022 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/pantry#readme
synopsis:             Content addressable Haskell package management
description:
    Please see the README on GitHub at <https://github.com/commercialhaskell/pantry#readme>

category:             Development
abi:                  b8601e03362316a73d0c4ffca94a43ca
exposed:              True
exposed-modules:
    Pantry Pantry.Internal Pantry.Internal.AesonExtended
    Pantry.Internal.Companion Pantry.Internal.Stackage
    Pantry.Internal.StaticBytes Pantry.SHA256

hidden-modules:
    Hackage.Security.Client.Repository.HttpLib.HttpClient
    Pantry.Archive Pantry.HTTP Pantry.HPack Pantry.Hackage Pantry.Repo
    Pantry.SQLite Pantry.Storage Pantry.Casa Pantry.Tree Pantry.Types
    System.IsWindows

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pantry
hs-libraries:         HSpantry-0.8.3-HeGJd6loLMhEqqlWfpBGUy
depends:
    Cabal-3.10.3.0 aeson-2.2.2.0-mVpxNJADFA3tVhrw9PzvG
    ansi-terminal-1.1-9hyTCG9puEj4dnXsh6uh7k base-4.18.2.1
    bytestring-0.11.5.3 casa-client-0.0.4-EttSm6TO49SGDbZdJfqbPF
    casa-types-0.0.3-8CCr9stksafFAToil3FG1s
    conduit-1.3.6.1-FIwCK0b1Hr15S6D1xh1znT
    conduit-extra-1.3.8-Ck6pOXJmJPw7MIsaJ1VnN1 containers-0.6.7
    crypton-1.0.5-AZiRYciVzaiGzchrza0W2Y
    crypton-conduit-0.2.3-5PZrVRMjjOX1J3xh5J3OC1
    digest-0.0.2.1-JWOwjMkQwx5F9nVaVojfVV
    filelock-0.1.1.9-VsAeLgvnYtBciT9CaGoHU
    generic-deriving-1.14.7-4uysLO1BPvDEVVw3DQD5zc
    hackage-security-0.6.3.2-J23DPR6YR6PLfe9dPdOmB0
    hpack-0.38.0-465Qub6BGQ25Q9EHOdg5UG
    http-client-0.7.19-EUgGdw3KTvRKxRF4wbGFhk
    http-client-tls-0.3.6.4-H3zfj6u59LA6yzNQrvZrZx
    http-conduit-2.3.9.1-EhOu3SIoVgTGe8LjY9FuRl
    http-download-0.2.1.0-GbzUPHLDP8HGhXerj3HdlQ
    http-types-0.12.4-1B8W97d7Bm7JkBvipzT6Xa
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5 mtl-2.3.1
    network-uri-2.6.4.2-6IsL4l5xPlJ2SbjqeOZPL6
    path-0.9.6-BxhS1zhBGPXAv36OYtgfyJ
    path-io-1.8.2-FuZ8g3n9DutKRzBsYyarXM
    persistent-2.14.6.1-FjSaC8vt16WJFMMjsyGz9E
    persistent-sqlite-2.13.3.0-KhF8RLkDHkICF7yjZBttmH
    primitive-0.9.1.0-J2dxudhiRepI2JRXVzckXt
    resourcet-1.3.0-Cuj4zJihfYr1ci2ntaM4ld
    rio-0.1.25.0-LWOHMGCbbKSB4B6QZAXfze
    rio-orphans-0.1.2.0-E5edubLwHnCKpDqPjvBF8l
    rio-prettyprint-0.1.9.0-J1uUVNn8aEfKm1pepDnWSq
    tar-conduit-0.4.1-5ih0nZ0z7DvJR90MfmKP3q text-2.0.2
    text-metrics-0.3.3-AzAQDORzuFZLgS2yyml9KF time-1.12.2
    transformers-0.6.1.0 unix-compat-0.7.4.1-CVij6K5GN6q30I6j86A2Op
    unliftio-0.2.25.1-7sR1Ziz3z9kDMr2BTZq7dj
    unordered-containers-0.2.21-8KUdGsL7zFhFWAw4aaEQtP
    vector-0.13.2.0-KNP2q6eDEp8AmnRr9wgHHB
    yaml-0.11.11.2-AvIOnZYyDpQErZ41Aggoi5
    zip-archive-0.4.3.2-8Q0j6ljLLvDzUzPSUe73B

haddock-interfaces:   /usr/share/doc/haskell-pantry/html/pantry.haddock
haddock-html:         /usr/share/doc/haskell-pantry/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

